@@ -1,12 +1,15 @@
 #include <Rcpp.h>
 #include <limits>
 #include <ctime>
+#include <random>
+#include <algorithm>
 
 #define VERBOSE 0
 
 using namespace Rcpp;
 
-inline int randWrapper(const int n) { return floor(unif_rand()*n); }
+// Unused: C++11 now uses std::shuffle - MFH
+// inline int randWrapper(const int n) { return floor(unif_rand()*n); }
 
 
 class MC {
@@ -61,17 +64,6 @@ public:
 
 };
 
-
-
-
-
-
-
-
-
-
-
-
 class EvoStream {
 public:
 
@@ -134,10 +126,7 @@ public:
   }
 
 
-
-
-  ////////////////////////// Interfacer
-
+  // RCpp Interface
 
   Rcpp::NumericMatrix get_microclusters(){
     int d = this->ndimensions();
@@ -161,7 +150,6 @@ public:
   }
 
 
-
   Rcpp::NumericMatrix get_macroclusters(){
 
     if(!this->init){
@@ -187,7 +175,6 @@ public:
   }
 
 
-
   Rcpp::NumericVector get_macroweights(){
 
     if(!this->init){
@@ -222,14 +209,7 @@ public:
 
   }
 
-
-
-
-
-
-
-  ////////////////////////////// Online component
-
+  // Online component
 
 
   void cluster(Rcpp::NumericMatrix data){
@@ -288,7 +268,6 @@ public:
 
 
 
-
   void cleanup(){
 
 #if VERBOSE >= 2
@@ -325,7 +304,6 @@ public:
   }
 
 
-
   void removeMicroCluster(int i){
 #if VERBOSE >= 2
     std::cout << "Remove Cluster " << i << std::endl;
@@ -334,7 +312,6 @@ public:
   }
 
 
-
   void insert(Rcpp::NumericVector distances, MC mc){
 
     // merge if within radius
@@ -359,24 +336,7 @@ public:
   }
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-  //////////////////////////////////// Offline component
-
-
+  // Offline component
 
 
   void evolution(){
@@ -389,9 +349,6 @@ public:
     std::vector<Rcpp::NumericMatrix> offsprings = this->recombination(selected); // recombine parents
     std::vector<Rcpp::NumericMatrix> mutants = this->mutation(offsprings); // mutate offspring
 
-
-
-
     for(unsigned int i=0; i<mutants.size(); i++){
       double fit = this->fitness(mutants[i]); // evaluate new solution
 
@@ -427,7 +384,6 @@ public:
   }
 
 
-
   void recluster(int generations){
     if(!this->init) return;
 
@@ -442,8 +398,6 @@ public:
   }
 
 
-
-
   void calculateFitness(){
 
 #if VERBOSE >= 3
@@ -458,8 +412,6 @@ public:
 #endif
   }
 
-
-
   double fitness(Rcpp::NumericMatrix centres){
     double result=0.0;
 
@@ -474,7 +426,6 @@ public:
   }
 
 
-
   void initialize(){
 #if VERBOSE >= 2
     std::cout << "Initialize Solutions" << std::endl;
@@ -497,7 +448,6 @@ public:
     this->init=1;
   }
 
-
   std::vector<Rcpp::NumericMatrix> selection(){
 
     // declare return value before rngscope http://gallery.rcpp.org/articles/random-number-generation/
@@ -514,7 +464,6 @@ public:
       probability[i] = this->macroFitness[i];
     }
 
-
     // sample two parents
     Rcpp::IntegerVector selected(2);
     for(int i=0; i<2; i++){
@@ -554,7 +503,6 @@ public:
     return(individuals);
   }
 
-
   // wrapper for easier change of recombination algorithm
   std::vector<Rcpp::NumericMatrix> recombination(std::vector<Rcpp::NumericMatrix> individuals){
     return(recombinationGAclust(individuals));
@@ -565,10 +513,8 @@ public:
     return(mutationGAclust(individuals));
   }
 
-
   // GA Clustering recombination approach
   std::vector<Rcpp::NumericMatrix> recombinationGAclust(std::vector<Rcpp::NumericMatrix> individuals){
-
     RNGScope rngScope;
 
     if(R::runif(0,1) < this->crossoverRate){
@@ -595,7 +541,6 @@ public:
     return(individuals);
   }
 
-
   // PESAII reclustering approach
   std::vector<Rcpp::NumericMatrix> recombinationPESAII(std::vector<Rcpp::NumericMatrix> individuals){
 
@@ -612,7 +557,6 @@ public:
       }
     }
 
-
 #if VERBOSE >= 3
     std::cout << "Offsprpring1:" << individuals[0] << std::endl;
     std::cout << "Offsprpring2:" << individuals[1] << std::endl;
@@ -622,7 +566,6 @@ public:
   }
 
 
-
   // GA Clustering mutation approach
   std::vector<Rcpp::NumericMatrix> mutationGAclust(std::vector<NumericMatrix> individuals){
 
@@ -683,11 +626,7 @@ public:
   }
 
 
-
-
-
-
-  ///////////////////////// Helper
+  // Helper
 
   Rcpp::IntegerVector getAssignment(Rcpp::NumericMatrix centres){
     Rcpp::IntegerVector assignment(this->micro.size());
@@ -707,7 +646,6 @@ public:
   }
 
 
-
   double getMaxFitness(){
     // find max fitness
     if(!this->init){
@@ -724,7 +662,6 @@ public:
   }
 
 
-
   int ndimensions(){
     if(!micro.size()){
       return(0);
@@ -734,7 +671,6 @@ public:
   }
 
 
-
   int sampleProportionally(Rcpp::NumericVector data){
 
     // declare return value before rngScope http://gallery.rcpp.org/articles/random-number-generation/
@@ -753,7 +689,6 @@ public:
   }
 
 
-
   Rcpp::NumericVector getDistanceVector(MC mc, std::vector<MC> cluster){
 
     Rcpp::NumericVector distances(cluster.size());
@@ -772,7 +707,11 @@ public:
     // declare return value before rngscope http://gallery.rcpp.org/articles/random-number-generation/
     RNGScope scope;
 
-    std::random_shuffle(b.begin(), b.end(), randWrapper);
+    // C11 random_shuffle is now shuffle - MFH
+    //std::random_shuffle(b.begin(), b.end(), randWrapper);
+    std::random_device rd;
+    std::mt19937 g(rd());
+    std::shuffle(b.begin(), b.end(), rd);
 
     return(b);
   }
@@ -781,12 +720,6 @@ public:
 };
 
 
-
-
-
-
-
-
 // Allows to return class objects to R
 RCPP_EXPOSED_CLASS(EvoStream)
   RCPP_EXPOSED_CLASS(MC)
@@ -795,7 +728,6 @@ RCPP_EXPOSED_CLASS(EvoStream)
   RCPP_MODULE(MOD_evoStream){
     using namespace Rcpp;
 
-
     class_<EvoStream>("EvoStream")
       .constructor()
 
@@ -821,6 +753,4 @@ RCPP_EXPOSED_CLASS(EvoStream)
     .method("fade", &MC::fade)
     ;
 
-
   }
-
